@@ -8,7 +8,7 @@ test_install_python3() {
     for py in $(py3versions -r 2>/dev/null) ; do
         cd "$AUTOPKGTEST_TMP" ;
         echo "Testing with $py:" ;
-        $py -c "import pyExploitDb; print(pyExploitDb)" ;
+        $py -c "import pyexploitdb; print(pyexploitdb)" ;
     done
 
 }
